@@ -1,6 +1,5 @@
 """Copy valid pixels from input files to an output file."""
 
-from __future__ import absolute_import
 
 import logging
 import math
@@ -8,14 +7,15 @@ import warnings
 
 import numpy as np
 
-from rasterio._base import get_window
+from rasterio import windows
+from rasterio.enums import Resampling
 from rasterio.transform import Affine
 
 
 logger = logging.getLogger(__name__)
 
 
-def merge(sources, bounds=None, res=None, nodata=None, precision=7):
+def merge(datasets, bounds=None, res=None, nodata=None, precision=7, indexes=None):
     """Copy valid pixels from input files to an output file.
 
     All files must have the same number of bands, data type, and
@@ -31,8 +31,8 @@ def merge(sources, bounds=None, res=None, nodata=None, precision=7):
 
     Parameters
     ----------
-    sources: list of source datasets
-        Open rasterio RasterReader objects to be merged.
+    datasets: list of dataset objects opened in 'r' mode
+        source datasets to be merged.
     bounds: tuple, optional
         Bounds of the output image (left, bottom, right, top).
         If not set, bounds are determined from bounds of input rasters.
@@ -43,28 +43,43 @@ def merge(sources, bounds=None, res=None, nodata=None, precision=7):
     nodata: float, optional
         nodata value to use in output file. If not set, uses the nodata value
         in the first input raster.
+    indexes : list of ints or a single int, optional
+        bands to read and merge
 
     Returns
     -------
-    dest: numpy ndarray
-        Contents of all input rasters in single array.
-    out_transform: affine object
-        Information for mapping pixel coordinates in `dest` to another
-        coordinate system
+    tuple
+
+        Two elements:
+
+            dest: numpy ndarray
+                Contents of all input rasters in single array
+
+            out_transform: affine.Affine()
+                Information for mapping pixel coordinates in `dest` to another
+                coordinate system
     """
-    first = sources[0]
+    first = datasets[0]
     first_res = first.res
     nodataval = first.nodatavals[0]
     dtype = first.dtypes[0]
 
-    # Extent from option or extent of all inputs.
+    # Determine output band count
+    if indexes is None:
+        output_count = first.count
+    elif isinstance(indexes, int):
+        output_count = 1
+    else:
+        output_count = len(indexes)
+
+    # Extent from option or extent of all inputs
     if bounds:
         dst_w, dst_s, dst_e, dst_n = bounds
     else:
-        # scan input files.
+        # scan input files
         xs = []
         ys = []
-        for src in sources:
+        for src in datasets:
             left, bottom, right, top = src.bounds
             xs.extend([left, right])
             ys.extend([bottom, top])
@@ -74,7 +89,7 @@ def merge(sources, bounds=None, res=None, nodata=None, precision=7):
     output_transform = Affine.translation(dst_w, dst_n)
     logger.debug("Output transform, before scaling: %r", output_transform)
 
-    # Resolution/pixel size.
+    # Resolution/pixel size
     if not res:
         res = first_res
     elif not np.iterable(res):
@@ -85,31 +100,34 @@ def merge(sources, bounds=None, res=None, nodata=None, precision=7):
     logger.debug("Output transform, after scaling: %r", output_transform)
 
     # Compute output array shape. We guarantee it will cover the output
-    # bounds completely.
+    # bounds completely
     output_width = int(math.ceil((dst_e - dst_w) / res[0]))
     output_height = int(math.ceil((dst_n - dst_s) / res[1]))
 
-    # Adjust bounds to fit.
+    # Adjust bounds to fit
     dst_e, dst_s = output_transform * (output_width, output_height)
     logger.debug("Output width: %d, height: %d", output_width, output_height)
     logger.debug("Adjusted bounds: %r", (dst_w, dst_s, dst_e, dst_n))
 
     # create destination array
-    dest = np.zeros((first.count, output_height, output_width), dtype=dtype)
+    dest = np.zeros((output_count, output_height, output_width), dtype=dtype)
 
     if nodata is not None:
         nodataval = nodata
         logger.debug("Set nodataval: %r", nodataval)
 
     if nodataval is not None:
-        # Only fill if the nodataval is within dtype's range.
+        # Only fill if the nodataval is within dtype's range
         inrange = False
         if np.dtype(dtype).kind in ('i', 'u'):
             info = np.iinfo(dtype)
             inrange = (info.min <= nodataval <= info.max)
         elif np.dtype(dtype).kind == 'f':
             info = np.finfo(dtype)
-            inrange = (info.min <= nodataval <= info.max)
+            if np.isnan(nodataval):
+                inrange = True
+            else:
+                inrange = (info.min <= nodataval <= info.max)
         if inrange:
             dest.fill(nodataval)
         else:
@@ -121,12 +139,12 @@ def merge(sources, bounds=None, res=None, nodata=None, precision=7):
     else:
         nodataval = 0
 
-    for src in sources:
+    for src in datasets:
         # Real World (tm) use of boundless reads.
-        # This approach uses the maximum amount of memory to solve the problem.
-        # Making it more efficient is a TODO.
+        # This approach uses the maximum amount of memory to solve the
+        # problem. Making it more efficient is a TODO.
 
-        # 1. Compute spatial intersection of destination and source.
+        # 1. Compute spatial intersection of destination and source
         src_w, src_s, src_e, src_n = src.bounds
 
         int_w = src_w if src_w > dst_w else dst_w
@@ -134,33 +152,36 @@ def merge(sources, bounds=None, res=None, nodata=None, precision=7):
         int_e = src_e if src_e < dst_e else dst_e
         int_n = src_n if src_n < dst_n else dst_n
 
-        # 2. Compute the source window.
-        src_window = get_window(
-            int_w, int_s, int_e, int_n, src.affine, precision=precision)
+        # 2. Compute the source window
+        src_window = windows.from_bounds(
+            int_w, int_s, int_e, int_n, src.transform, precision=precision)
         logger.debug("Src %s window: %r", src.name, src_window)
 
-        # 3. Compute the destination window.
-        dst_window = get_window(
+        src_window = src_window.round_shape()
+
+        # 3. Compute the destination window
+        dst_window = windows.from_bounds(
             int_w, int_s, int_e, int_n, output_transform, precision=precision)
-        logger.debug("Dst window: %r", dst_window)
 
-        # 4. Initialize temp array.
-        tcount = first.count
-        trows, tcols = tuple(b - a for a, b in dst_window)
+        # 4. Read data in source window into temp
+        trows, tcols = (
+            int(round(dst_window.height)), int(round(dst_window.width)))
+        temp_shape = (output_count, trows, tcols)
+        temp = src.read(out_shape=temp_shape, window=src_window,
+                        boundless=False, masked=True, indexes=indexes)
 
-        temp_shape = (tcount, trows, tcols)
-        logger.debug("Temp shape: %r", temp_shape)
-
-        temp = np.zeros(temp_shape, dtype=dtype)
-        temp = src.read(out=temp, window=src_window, boundless=False,
-                        masked=True)
-
-        # 5. Copy elements of temp into dest.
-        roff, coff = dst_window[0][0], dst_window[1][0]
+        # 5. Copy elements of temp into dest
+        roff, coff = (
+            int(round(dst_window.row_off)), int(round(dst_window.col_off)))
 
         region = dest[:, roff:roff + trows, coff:coff + tcols]
-        np.copyto(
-            region, temp,
-            where=np.logical_and(region == nodataval, temp.mask == False))
+        if np.isnan(nodataval):
+            region_nodata = np.isnan(region)
+            temp_nodata = np.isnan(temp)
+        else:
+            region_nodata = region == nodataval
+            temp_nodata = temp.mask
+        mask = np.logical_and(region_nodata, ~temp_nodata)
+        np.copyto(region, temp, where=mask)
 
     return dest, output_transform
